/* ====================================================================
 *  Copyright 2003-2004 Paul Querna
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 * ====================================================================
 */

/**
 * Author: Paul Querna <chip force-elite.com>
 *
 *  Originaly Based on mod_mysql_pool by Nick Kew:
 *    http://apache.webthing.com/
 *
 * $Id: mod_dbi_pool_private.h 209 2004-06-19 22:35:50Z chip $
 */

/**
 * mod_dbi_pool: manage a pool of libdbi connections.
 */

#include "httpd.h"
#include "http_protocol.h"
#include "http_config.h"
#include "http_log.h"
#include "apr.h"
#include "apu.h"
#include "apr_pools.h"
#include "apr_errno.h"
#include "apr_time.h"
#include "apr_strings.h"
#include "apr_hash.h"
#include "apr_reslist.h"
#include "dbi/dbi.h"

#ifndef _INCLUDE_MOD_DBI_POOL_PRIVATE_H
#define _INCLUDE_MOD_DBI_POOL_PRIVATE_H


#define DFLT_DBI_DBNAME "mod_dbi"
#define DFLT_DBI_HOST "localhost"
#define DFLT_DBI_DRIVER "mysql"
#define DFLT_DBI_USER "root"
#define DFLT_DBI_PASS ""        
/**
 * setting this to NULL triggers a bug in libdbi which causes a segfault. mysql docs
 * say this must be set to NULL in order to login without a password. fortunately,
 * setting "" works as well. the bug is reported to the libdbi maintainers. we will
 * change this back when the bug is fixed.
 */

#define DFLT_CONN_MIN (1)
#define DFLT_CONN_SOFT (5)
#define DFLT_CONN_MAX (25)
#define DFLT_CONN_TTL (600)
#define DFLT_OPTIONS (0)
#ifndef DBI_HARD_MAX_CONNS
#define DBI_HARD_MAX_CONNS (255)
#endif

typedef enum
{
    CONF_DBI_DRIVER,
    CONF_DBI_DRIVER_DIR,
    CONF_DBI_HOST,
    CONF_DBI_USERNAME,
    CONF_DBI_PASSWORD,
    CONF_DBI_DBNAME,
    CONF_DBI_CONN_MIN,
    CONF_DBI_CONN_SOFTMAX,
    CONF_DBI_CONN_HARDMAX,
    CONF_DBI_CONN_TTL,
} CONF_DBI;

typedef struct dbi_config_rec_struct
{
    const char *dbi_dbname;
    const char *dbi_user;
    const char *dbi_pass;
    const char *dbi_driver;
    const char *dbi_host;
    int conn_min;
    int conn_soft;
    int conn_max;
    int conn_ttl;
} dbi_config_rec;

#endif
